@@ -78,6 +78,31 @@ HotkeyMonitor::getHotkeyFor(Qt::Key key, Qt::KeyboardModifiers modifiers)
     return hotkey;
 }
 
+Hotkey*
+HotkeyMonitor::getHotkeyFor(uint x11Keycode, Qt::KeyboardModifiers modifiers)
+{
+    Q_FOREACH(Hotkey* currentHotkey, m_hotkeys) {
+        if (currentHotkey->x11key() == x11Keycode &&
+            currentHotkey->modifiers() == modifiers) {
+            return currentHotkey;
+        }
+    }
+
+    Hotkey *hotkey = new Hotkey(x11Keycode, modifiers, this);
+    m_hotkeys.append(hotkey);
+    return hotkey;
+}
+
+void HotkeyMonitor::disableModifiers(Qt::KeyboardModifiers modifiers)
+{
+    m_disabledModifiers |= modifiers;
+}
+
+void HotkeyMonitor::enableModifiers(Qt::KeyboardModifiers modifiers)
+{
+    m_disabledModifiers &= ~modifiers;
+}
+
 bool
 HotkeyMonitor::keyEventFilter(void* message)
 {
@@ -85,21 +110,31 @@ HotkeyMonitor::keyEventFilter(void* message)
     if (event->type == KeyRelease || event->type == KeyPress)
     {
         XKeyEvent* key = (XKeyEvent*) event;
-        HotkeyMonitor::instance().processKeyEvent(key->keycode, key->state,
-                                                  event->type == KeyPress);
+        if (HotkeyMonitor::instance().processKeyEvent(key->keycode, key->state,
+                                                      event->type == KeyPress)) {
+            return true;
+        }
     }
     return false;
 }
 
-void
+bool
 HotkeyMonitor::processKeyEvent(uint x11Keycode, uint x11Modifiers,
                                bool isPressEvent)
 {
     Q_FOREACH(Hotkey* hotkey, m_hotkeys) {
+        if (hotkey->modifiers() & m_disabledModifiers) {
+            /* If any of the hotkey's modifiers have been disabled, the hotkey
+             * cannot be triggered */
+            continue;
+        }
+
         if (hotkey->processNativeEvent(x11Keycode, x11Modifiers, isPressEvent)) {
-            return;
+            return true;
         }
     }
+
+    return false;
 }
 
 #include "hotkeymonitor.moc"
