@@ -31,8 +31,6 @@ class FdoSelectionManager;
 class Task;
 }
 
-class QConf;
-
 class LegacyTrayApplet : public Unity2d::PanelApplet
 {
 Q_OBJECT
@@ -48,8 +46,8 @@ private:
     Q_DISABLE_COPY(LegacyTrayApplet)
     
     SystemTray::FdoSelectionManager* m_selectionManager;
-    QConf* m_dconfPanel;
     QStringList m_whitelist;
+    bool m_whitelistAll;
 };
 
 #endif /* LEGACYTRAYAPPLET_H */
