@@ -30,23 +30,13 @@ class SpreadView : public Unity2DDeclarativeView
     Q_OBJECT
 
 public:
-    explicit SpreadView();
+    explicit SpreadView(int screen);
 
 public Q_SLOTS:
-    /* FIXME: copied from places/app/dashdeclarativeview.h */
-    void fitToAvailableSpace(int screen);
-
-protected:
-    virtual void focusInEvent( QFocusEvent * event );
-    virtual void focusOutEvent( QFocusEvent * event );
-    virtual void showEvent(QShowEvent *event);
-    virtual void hideEvent(QHideEvent *event);
-    bool eventFilter(QObject *obj, QEvent *event);
-
-Q_SIGNALS:
-    void outsideClick();
-    void visibleChanged(bool visible);
+    void fitToAvailableSpace();
 };
 
+Q_DECLARE_METATYPE(SpreadView*)
+
 #endif // SPREADVIEW_H
 
